<?php
use Drupal\Core\Form\FormStateInterface;
use Drupal\file\Entity\File;
use Drupal\Core\Ajax\CommandInterface;

function pexre_form_system_theme_settings_alter(&$form, \Drupal\Core\Form\FormStateInterface &$form_state, $form_id = NULL) {
    // Work-around for a core bug affecting admin themes. See issue #943212.
    $theme_file = drupal_get_path('theme', 'pexre') . '/theme-settings.php';
    $build_info = $form_state->getBuildInfo();
    if (!in_array($theme_file, $build_info['files'])) {
        $build_info['files'][] = $theme_file;
    }
    $form_state->setBuildInfo($build_info);

    $form['#submit'][] = 'pexre_theme_settings_form_submit';
    $form['#attached']['library'][] = 'pexre/theme-settings';
    $form['advanced'] = array(
        '#type' => 'vertical_tabs',
        '#default_tab' => 'general_setting',
    );
    $form['general_setting'] = array(
        '#type' => 'details',
        '#title' => t('General Settings'),
        '#group' => 'advanced',
    );
    if (!\Drupal::moduleHandler()->moduleExists('yaml_editor')) {
        $message = t('<strong>It is recommended to install the</strong> <a href="@yaml-editor">YAML Editor</a> module for easier editing.', [
            '@yaml-editor' => 'https://www.drupal.org/project/yaml_editor',
        ]);

        //drupal_set_message($message, 'warning');
        $form['general_setting']['status_messages'] = [
           '#markup' => $message
        ];
    }
    $form['general_setting']['tracking_code'] = array(
        '#type'          => 'textarea',
        '#title'         => t('Tracking Code'),
        '#default_value' => theme_get_setting('tracking_code', 'pexre'),
        '#description'   => t("Add custom script on your site."),
    );
    $form['general_setting']['custom_css'] = array(
        '#type'          => 'textarea',
        '#title'         => t('Custom CSS'),
        '#default_value' => theme_get_setting('custom_css', 'pexre'),
        '#description'   => t('<strong>Example:</strong><br/>h1 { font-family: \'Metrophobic\', Arial, serif; font-weight: 400; }'),
    );
    $form['header_settings'] = array(
        '#type' => 'details',
        '#title' => t('Header Settings'),
        '#group' => 'advanced',
    );

    //Header settings
    $form['header_settings']['header_layout'] = array(
        '#type'          => 'select',
        '#title'         => t('Header layout'),
        '#options' => array(
            'layout1' => t('Layout 1'),
            'layout2' => t('Layout 2'),
            'layout3' => t('Layout 3'),
            'layout4' => t('Layout 4'),
            'layout5' => t('Layout 5'),
        ),
        '#default_value' => theme_get_setting('header_layout', 'pexre'),
    );
    $form['header_settings']['header_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Header class'),
        '#default_value' => theme_get_setting('header_class', 'pexre'),
    );
    $form['header_settings']['topbar_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Topbar class'),
        '#default_value' => theme_get_setting('topbar_class', 'pexre'),
    );
    //Footer settings
    $form['footer_settings'] = array(
        '#type' => 'details',
        '#title' => t('Footer Settings'),
        '#group' => 'advanced',
    );
    $form['footer_settings']['footer_background_image'] = array(
            '#type'     => 'managed_file',
            '#title'    => t('Footer background image upload'),
            '#required' => FALSE,
            '#upload_location' => 'public://background/',
            '#default_value' => theme_get_setting('footer_background_image','pexre'),
            '#upload_validators' => array(
            'file_validate_extensions' => array('gif png jpg jpeg'),
            '#progress_message' => 'Uploading ...',
            '#required' => FALSE,
        ),
    );
    $form['footer_settings']['footer_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Footer class'),
        '#default_value' => theme_get_setting('footer_class', 'pexre'),
    );
    $form['footer_settings']['footer_copyright_message'] = array(
        '#type'          => 'textarea',
        '#title'         => t('Footer copyright message'),
        '#default_value' => theme_get_setting('footer_copyright_message', 'pexre'),
    );
    $form['footer_settings']['footer_bottom_right'] = array(
        '#type'          => 'textarea',
        '#title'         => t('Footer bottom right'),
        '#default_value' => theme_get_setting('footer_bottom_right', 'pexre'),
    );

    //Portfolio settings
    $form['portfolio_settings'] = array(
        '#type' => 'details',
        '#title' => t('Portfolio Settings'),
        '#group' => 'advanced',
    );
    $form['portfolio_settings']['portfolio_style'] = array(
        '#type'          => 'select',
        '#title'         => t('Portfolio style'),
        '#options' => array(
            '2cols' => t('Portfolio two'),
            '3cols' => t('Portfolio three'),
            '4cols' => t('Portfolio four'),
            'mosaic' => t('Classic mosaic'),
            'mosaic_flat' => t('Classic mosaic flat'),
            'masonry' => t('Classic masonry'),
            'masonry_projects' => t('Masonry projects'),
            'slider_projects' => t('Slider projects'),
            'fullwidth' => t('Masonry fullwidth'),
            'modern' => t('Modern'),
            'sidebar_left' => t('Left sidebar'),
            'sidebar_right' => t('Right sidebar'),
        ),
        '#default_value' => theme_get_setting('portfolio_style', 'pexre'),
    );
    $form['portfolio_settings']['portfolio_header_layout'] = array(
        '#type'          => 'select',
        '#title'         => t('Header layout'),
        '#options' => array(
            'layout1' => t('Layout 1'),
            'layout2' => t('Layout 2'),
            'layout3' => t('Layout 3'),
            'layout4' => t('Layout 4'),
            'layout5' => t('Layout 5'),
        ),
        '#default_value' => theme_get_setting('portfolio_header_layout', 'pexre'),
    );
    $form['portfolio_settings']['portfolio_header_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Header class'),
        '#default_value' => theme_get_setting('portfolio_header_class', 'pexre'),
    );
    $form['portfolio_settings']['portfolio_topbar_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Topbar class'),
        '#default_value' => theme_get_setting('portfolio_topbar_class', 'pexre'),
    );
    $form['portfolio_settings']['portfolio_page_title_style'] = array(
        '#type'          => 'select',
        '#title'         => t('Page title style'),
        '#options' => array(
            'image_white' => t('Background image white title'),
            'slogan' => t('Background image with slogan'),
            'default' => t('Default'),
        ),
        '#default_value' => theme_get_setting('portfolio_page_title_style', 'pexre'),
    );
    $form['portfolio_settings']['portfolio_page_title_bgimage'] = array(
            '#type'     => 'managed_file',
            '#title'    => t('Page title background image upload'),
            '#required' => FALSE,
            '#upload_location' => 'public://background/',
            '#default_value' => theme_get_setting('portfolio_page_title_bgimage','pexre'),
            '#upload_validators' => array(
            'file_validate_extensions' => array('gif png jpg jpeg'),
            '#progress_message' => 'Uploading ...',
            '#required' => FALSE,
        ),
    );
    $form['portfolio_settings']['portfolio_slogan'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Portfolio slogan'),
        '#default_value' => theme_get_setting('portfolio_slogan', 'pexre'),
    );

    //Blog settting
    $form['blog_settings'] = array(
        '#type' => 'details',
        '#title' => t('Blog Settings'),
        '#group' => 'advanced',
    );
    $form['blog_settings']['blog_layout'] = array(
        '#type'          => 'select',
        '#title'         => t('Blog layout'),
        '#options' => array(
            'grid' => t('Grid'),
            'standard' => t('Standard'),
            'classic' => t('Classic'),
            'sidebar_left' => t('Sidebar left'),
            'sidebar_right' => t('Sidebar right'),
            'big_text' => t('Big text'),
        ),
        '#default_value' => theme_get_setting('blog_layout', 'pexre'),
    );
    $form['blog_settings']['blog_header_layout'] = array(
        '#type'          => 'select',
        '#title'         => t('Header layout'),
        '#options' => array(
            'layout1' => t('Layout 1'),
            'layout2' => t('Layout 2'),
            'layout3' => t('Layout 3'),
            'layout4' => t('Layout 4'),
            'layout5' => t('Layout 5'),
        ),
        '#default_value' => theme_get_setting('blog_header_layout', 'pexre'),
    );
    $form['blog_settings']['blog_header_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Header class'),
        '#default_value' => theme_get_setting('blog_header_class', 'pexre'),
    );
    $form['blog_settings']['blog_topbar_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Topbar class'),
        '#default_value' => theme_get_setting('blog_topbar_class', 'pexre'),
    );
    $form['blog_settings']['blog_page_title_style'] = array(
        '#type'          => 'select',
        '#title'         => t('Page title style'),
        '#options' => array(
            'image_white' => t('Background image white title'),
            'slogan' => t('Background image with slogan'),
            'default' => t('Default'),
        ),
        '#default_value' => theme_get_setting('blog_page_title_style', 'pexre'),
    );
    $form['blog_settings']['blog_page_title_bgimage'] = array(
            '#type'     => 'managed_file',
            '#title'    => t('Page title background image upload'),
            '#required' => FALSE,
            '#upload_location' => 'public://background/',
            '#default_value' => theme_get_setting('blog_page_title_bgimage','pexre'),
            '#upload_validators' => array(
            'file_validate_extensions' => array('gif png jpg jpeg'),
            '#progress_message' => 'Uploading ...',
            '#required' => FALSE,
        ),
    );
    $form['blog_settings']['blog_slogan'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Blog slogan'),
        '#default_value' => theme_get_setting('blog_slogan', 'pexre'),
    );

    //Shop settting
    $form['shop_settings'] = array(
        '#type' => 'details',
        '#title' => t('Shop Settings'),
        '#group' => 'advanced',
    );
    $form['shop_settings']['shop_layout'] = array(
        '#type'          => 'select',
        '#title'         => t('Shop layout'),
        '#options' => array(
            'fullwidth' => t('Full Width'),
            'grid_2cols' => t('Grid 2 Columns'),
            'grid_3cols' => t('Grid 3 Columns'),
            'grid_4cols' => t('Grid 4 Columns'),
            'grid_5cols' => t('Grid 5 Columns'),
            'grid_6cols' => t('Grid 6 Columns'),
            'left_sidebar' => t('Left sidebar'),
            'right_sidebar' => t('Right sidebar')
        ),
        '#default_value' => theme_get_setting('shop_layout', 'pexre'),
    );
    $form['shop_settings']['shop_header_layout'] = array(
        '#type'          => 'select',
        '#title'         => t('Header layout'),
        '#options' => array(
            'layout1' => t('Layout 1'),
            'layout2' => t('Layout 2'),
            'layout3' => t('Layout 3'),
            'layout4' => t('Layout 4'),
            'layout5' => t('Layout 5'),
        ),
        '#default_value' => theme_get_setting('shop_header_layout', 'pexre'),
    );
    $form['shop_settings']['shop_header_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Header class'),
        '#default_value' => theme_get_setting('shop_header_class', 'pexre'),
    );
    $form['shop_settings']['shop_topbar_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Topbar class'),
        '#default_value' => theme_get_setting('shop_topbar_class', 'pexre'),
    );
    $form['shop_settings']['shop_page_title_style'] = array(
        '#type'          => 'select',
        '#title'         => t('Page title style'),
        '#options' => array(
            'image_white' => t('Background image white title'),
            'slogan' => t('Background image with slogan'),
            'default' => t('Default'),
        ),
        '#default_value' => theme_get_setting('shop_page_title_style', 'pexre'),
    );
    $form['shop_settings']['shop_page_title_bgimage'] = array(
            '#type'     => 'managed_file',
            '#title'    => t('Page title background image upload'),
            '#required' => FALSE,
            '#upload_location' => 'public://background/',
            '#default_value' => theme_get_setting('shop_page_title_bgimage','pexre'),
            '#upload_validators' => array(
            'file_validate_extensions' => array('gif png jpg jpeg'),
            '#progress_message' => 'Uploading ...',
            '#required' => FALSE,
        ),
    );
    $form['shop_settings']['shop_slogan'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Blog slogan'),
        '#default_value' => theme_get_setting('shop_slogan', 'pexre'),
    );
    $form['shop_settings']['product_style'] = array(
        '#type'          => 'select',
        '#title'         => t('Single product style'),
        '#options' => array(
            'fullwidth' => t('Full Width'),
            'left_sidebar' => t('Left sidebar'),
            'right_sidebar' => t('Right sidebar'),
        ),
        '#default_value' => theme_get_setting('product_style', 'pexre'),
    );

    //Page settings
    $form['page_settings'] = array(
        '#type' => 'details',
        '#title' => t('Pages Settings'),
        '#group' => 'advanced',
    );
    $form['page_settings']['page_header_layout'] = array(
        '#type'          => 'select',
        '#title'         => t('Header layout'),
        '#options' => array(
            'layout1' => t('Layout 1'),
            'layout2' => t('Layout 2'),
            'layout3' => t('Layout 3'),
            'layout4' => t('Layout 4'),
            'layout5' => t('Layout 5'),
        ),
        '#default_value' => theme_get_setting('page_header_layout', 'pexre'),
    );
    $form['page_settings']['page_header_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Header class'),
        '#default_value' => theme_get_setting('page_header_class', 'pexre'),
    );
    $form['page_settings']['page_topbar_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Topbar class'),
        '#default_value' => theme_get_setting('page_topbar_class', 'pexre'),
    );
    $form['page_settings']['system_page_title_bgimage'] = array(
        '#type'     => 'managed_file',
        '#title'    => t('Page title background image upload'),
        '#required' => FALSE,
        '#upload_location' => 'public://background/',
        '#default_value' => theme_get_setting('system_page_title_bgimage','pexre'),
        '#upload_validators' => array(
            'file_validate_extensions' => array('gif png jpg jpeg'),
            '#progress_message' => 'Uploading ...',
            '#required' => FALSE,
        ),
    );
    $form['page_settings']['page_title_class'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Page class title'),
        '#default_value' => theme_get_setting('page_title_class', 'pexre'),
    );

    //Contact settings
    $form['contact_settings'] = array(
        '#type' => 'details',
        '#title' => t('Contact Settings'),
        '#group' => 'advanced',
    );
    $form['contact_settings']['contact_google_map_api'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Google map API'),
        '#default_value' => theme_get_setting('contact_google_map_api', 'pexre'),
        '#description'   => t('Google requires users to use a valid API key. Using the <a href="https://console.developers.google.com/apis" target="_blank">Google API Manager</a>, you can enable the Google Maps JavaScript API. That will create (or reuse) a Browser key which you can paste here.')
    );
    $form['contact_settings']['contact_geo_latitude'] = array(
        '#type'          => 'textfield',
        '#title'         => t('GeoLocation Latitude'),
        '#default_value' => theme_get_setting('contact_geo_latitude', 'pexre'),
    );
    $form['contact_settings']['contact_geo_longitude'] = array(
        '#type'          => 'textfield',
        '#title'         => t('GeoLocation Longitude'),
        '#default_value' => theme_get_setting('contact_geo_longitude', 'pexre'),
    );
    $form['contact_settings']['contact_geolocation_icon'] = array(
        '#type'     => 'managed_file',
        '#title'    => t('GeoLocation icon'),
        '#required' => FALSE,
        '#upload_location' => 'public://background/',
        '#default_value' => theme_get_setting('contact_geolocation_icon','pexre'),
        '#upload_validators' => array(
            'file_validate_extensions' => array('gif png jpg jpeg'),
            '#progress_message' => 'Uploading ...',
            '#required' => FALSE,
        ),
    );
    $form['contact_settings']['contact_map_zoom'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Map zoom'),
        '#default_value' => theme_get_setting('contact_map_zoom', 'pexre'),
    );

}

function pexre_theme_settings_form_submit(&$form, FormStateInterface $form_state) {
    $image_fid[0] = $form_state->getValue('blog_page_title_bgimage');
    $image_fid[1] = $form_state->getValue('portfolio_page_title_bgimage');
    $image_fid[2] = $form_state->getValue('system_page_title_bgimage');
    $image_fid[3] = $form_state->getValue('shop_page_title_bgimage');
    $image_fid[4] = $form_state->getValue('contact_geolocation_icon');
    $image_fid[5] = $form_state->getValue('footer_background_image');
    $count = count($image_fid);
    for ($i=0; $i < $count; $i++) {
        if( $image_fid[$i]) {
            $file = File::load($image_fid[$i][0]);
            $file_usage = \Drupal::service('file.usage');
            $file_usage->add($file, 'pexre', 'theme', 1);
        }
    }
        
}
?>